@@ -4,33 +4,30 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 use Acme::CPANAuthors::Register(
     q(AAR) => q(Alessandro Ranellucci),
-    q(AASSAD) => q(Arnaud "Arhuman" Assad),
-    q(ABERNDT) => q(Alan Berndt),
     q(ABH) => q(Ask Bjørn Hansen),
     q(ABIGAIL) => q(Abigail),
     q(ABRAXXA) => q(Alexander Hartmaier),
-    q(ABW) => q(Andy Wardley),
     q(ACAJOU) => q(Pascal Gaudette),
     q(ACCARDO) => q(Michael Accardo),
     q(ADIE) => q(Adrian Howard),
+    q(ADUITSIS) => q(Athanasios Douitsis),
     q(ADULAU) => q(Alexandre Dulaunoy),
     q(AERO) => q(C.H. Kang),
     q(AFLOTT) => q(Adam Flott),
     q(AGENT) => q(agentzh (章亦春)),
-    q(AGORMAN) => q(Andy Gorman),
     q(AGRUNDMA) => q(Andy Grundman),
+    q(AHARONI) => q(אמיר א׳ אהרוני),
     q(AJCT) => q(Adam Taylor),
     q(AJGB) => q(Alex J. G. Burzyński),
-    q(AJGOUGH) => q(Alex Gough),
+    q(ALEX) => q(Alex J. Avriette),
     q(ALEXBIO) => q(Alessandro Ghedini),
     q(ALEXM) => q(Alex Muntada),
     q(ALEXMV) => q(Alex Vandiver),
-    q(AMBS) => q(Alberto Manuel Brandão Simões),
     q(AMD) => q(AMD OSRC (AMD Operating System Research Center)),
     q(AMIRI) => q(Amiri Barksdale),
     q(ANDK) => q(Andreas J. König),
@@ -38,24 +35,30 @@ use Acme::CPANAuthors::Register(
     q(ANDYA) => q(Andy Armstrong),
     q(ANELSON) => q(Andrew Nelson),
     q(ANIRVAN) => q(Anirvan Chatterjee),
+    q(ANNELI) => q(Anneli Cuss),
     q(ANSGAR) => q(Ansgar Burchardt),
     q(APOCAL) => q(Apocalypse),
-    q(AQUILINA) => q(Michael Aquilina),
+    q(APRIME) => q(Adam Prime),
     q(ARC) => q(Aaron Crane),
     q(ARCANEZ) => q(Justin Hunter),
     q(ARISTOTLE) => q(Αριστοτέλης Παγκαλτζής),
+    q(ARJONES) => q(Andrew Jones),
     q(ARODLAND) => q(Andrew Rodland),
+    q(ARPI) => q(Árpád Szász),
     q(ARUNBEAR) => q(Arun Prasaad),
     q(ASH) => q(Ash Berlin),
     q(ASHLEY) => q(Ashley Pond V — 바보 양키스),
+    q(ASPIERS) => q(Adam Spiers),
+    q(ATHOMASON) => q(Adam Thomason),
     q(ATOM) => q(Adam J. Foxson),
     q(AUDREYT) => q(☻ 唐鳳 ☺),
     q(AVAR) => q(Ævar Arnfjörð Bjarmason),
     q(AVUSEROW) => q(Adrian Kreher),
-    q(AWNCORP) => q(Al Newkirk & Associates),
+    q(AWNCORP) => q(ANAIO),
     q(AYOUNG) => q(Alan Young),
-    q(AZAWAWI) => q(أحمد محمد زواوي - Ahmad M. Zawawi),
     q(BARBIE) => q(Barbie),
+    q(BAREFOOT) => q(Buddy Burden),
+    q(BARNEY) => q(Branislav Zahradník),
     q(BAYASHI) => q(Dai Okabayashi),
     q(BCHOATE) => q(Brad Choate),
     q(BDFOY) => q(brian d foy),
@@ -70,9 +73,7 @@ use Acme::CPANAuthors::Register(
     q(BIGPRESH) => q(David Precious),
     q(BINGOS) => q(Chris Williams),
     q(BKANEY) => q(Brian Kaney),
-    q(BKB) => q(Ben Bullock),
     q(BLAIZER) => q(Blaise Roth),
-    q(BLHOTSKY) => q(Brad Lhotsky),
     q(BLUEFEET) => q(Aran Clary Deltac),
     q(BMORROW) => q(Ben Morrow),
     q(BOBTFISH) => q(Tomas Doran),
@@ -87,8 +88,8 @@ use Acme::CPANAuthors::Register(
     q(BRUNOV) => q(Bruno Vecchi),
     q(BTROTT) => q(Benjamin Trott),
     q(BUNDACIA) => q(Trevor Little),
-    q(BURAK) => q(Burak Gürsoy),
     q(CADAVIS) => q(Chad A Davis),
+    q(CAPTTOFU) => q(Patrick Galbraith),
     q(CARWASH) => q(Marcus Smith),
     q(CBRADFORD) => q(Colin Bradford),
     q(CEBJYRE) => q(Glenn Fowler),
@@ -109,16 +110,17 @@ use Acme::CPANAuthors::Register(
     q(CLKAO) => q(Chia-liang Kao (高嘉良)),
     q(CMCKAY) => q(Christopher Mckay),
     q(CNANGEL) => q(李俊良),
+    q(CONO) => q(Варяник Алексей),
     q(CORION) => q(Max Maischein),
     q(CORNELIUS) => q(Yo-An Lin (林佑安)),
     q(COSIMO) => q(Cosimo Streppone),
     q(CRAFTWORK) => q(Craftworks),
     q(CRENZ) => q(Christian Renz),
     q(CROMEDOME) => q(Jason A. Crome),
-    q(CSJEWELL) => q(Curtis Jewell),
+    q(CRUX) => q(Vladimir Lettiev),
     q(CVEGA) => q(Casey Vega),
     q(DAGOLDEN) => q(David Golden),
-    q(DAKKAR) => q(Gianni Ceccarelli),
+    q(DAM) => q(Дамян Иванов),
     q(DAMOG) => q(David Moreno),
     q(DAMS) => q(Damien Krotkine),
     q(DANBOO) => q(Daniel B. Boorstein),
@@ -128,18 +130,24 @@ use Acme::CPANAuthors::Register(
     q(DANKOGAI) => q(Dan Kogai),
     q(DANMOORE) => q(Dan Moore),
     q(DAPATRICK) => q(Darian Anthony Patrick),
-    q(DARREN) => q(Darren Chamberlain),
     q(DATA) => q(Danijel Tašov),
     q(DAVECROSS) => q(Dave Cross),
+    q(DAVIDO) => q(David J. Oswald),
     q(DAXIM) => q(Lars Dɪᴇᴄᴋᴏᴡ 迪拉斯),
     q(DBARTLE) => q(David Bartle),
+    q(DBB) => q(Daniel Bolton),
     q(DCHESTER) => q(David Chester),
+    q(DDAY) => q(David L. Day),
+    q(DELON) => q(Delon Newman),
+    q(DERF) => q(Daniel Friesel),
     q(DEXTER) => q(Piotr Roszatycki),
     q(DFH) => q(David F. Houghton),
     q(DGL) => q(David Leadbeater),
     q(DHOSS) => q(Devin Austin),
+    q(DICHI) => q(Mariano Wahlmann),
     q(DIEGOK) => q(Diego Kuperman),
     q(DKOGAN) => q(Dima Kogan),
+    q(DLAMBLEY) => q(Dave Lambley),
     q(DMAKI) => q(Daisuke Maki),
     q(DMITRYNOD) => q(Дмитрий Константинов),
     q(DOGGY) => q(Pan Fan (nightsailer)),
@@ -157,6 +165,7 @@ use Acme::CPANAuthors::Register(
     q(DROLSKY) => q(Dave Rolsky),
     q(DRTECH) => q(Clinton Gormley),
     q(DRUOSO) => q(Daniel Ruoso),
+    q(DUELAFN) => q(Dean Serenevy),
     q(DUFF) => q(Jonathan Scott Duff),
     q(DUNCAND) => q(Darren Duncan),
     q(DUNCS) => q(Duncan Ferguson),
@@ -169,9 +178,10 @@ use Acme::CPANAuthors::Register(
     q(EGILES) => q(Evan Giles),
     q(ELLIOTT) => q(Simon Elliott),
     q(EMAZEP) => q(Emanuele Zeppieri),
+    q(ENELL) => q(Enrique Nell),
     q(ESSELENS) => q(Tim Esselens),
     q(ETHER) => q(Karen Etheridge),
-    q(EVANK) => q(Evan S Kaufman),
+    q(EXC) => q(Viliam Pucik),
     q(EXODIST) => q(Chad Granum),
     q(FANGLY) => q(Florent Angly),
     q(FAYLAND) => q(Fayland 林),
@@ -179,13 +189,14 @@ use Acme::CPANAuthors::Register(
     q(FLORA) => q(Florian Ragwitz),
     q(FLORIAN) => q(Florian Helmberger),
     q(FMARIER) => q(François Marier),
-    q(FORWARD) => q(A.Vieth),
+    q(FOXCOOL) => q(Alexander Babenko),
     q(FRANCKC) => q(Franck Cuny),
     q(FRANKS) => q(Frank Sheiness),
     q(FREW) => q(Arthur Axel "fREW" Schmidt),
     q(FRIED) => q(Jason Fried),
     q(FRODWITH) => q(Paul Driver),
     q(FROGGS) => q(Tobias Leich),
+    q(FVOX) => q(Junior Moraes),
     q(FWIE) => q(Frank Wiegand),
     q(GAAS) => q(Gisle Aas),
     q(GANGLION) => q(Joel Roth),
@@ -203,9 +214,7 @@ use Acme::CPANAuthors::Register(
     q(GRODITI) => q(Guillermo Roditi),
     q(GSHANK) => q(Gerda Shank),
     q(GSLIN) => q(Gea-Suan Lin),
-    q(GTERMARS) => q(Graham TerMarsch),
     q(GUGOD) => q(劉康民),
-    q(GUGU) => q(Андрій Костенко),
     q(GWADEJ) => q(G. Wade Johnson),
     q(GWILLIAMS) => q(Gregory Todd Williams),
     q(HAARG) => q(Graham Knop),
@@ -215,11 +224,13 @@ use Acme::CPANAuthors::Register(
     q(HATENA) => q(はてな (Hatena, Inc.)),
     q(HAWK) => q(Jesper Dangaard Brouer),
     q(HDP) => q(Hans Dieter Pearcey),
+    q(HERNAN) => q(Hernan Lopes),
     q(HIDE) => q(Hideo Kimura),
     q(HIDEAKIO) => q(Hideaki Ohno),
     q(HINNERK) => q(Hinnerk Altenburg),
     q(HINRIK) => q(Hinrik Örn Sigurðsson),
     q(HIRAFOO) => q(Tomoya Hirano),
+    q(HIRATARA) => q(本間 雅洋 (Masahiro Honma)),
     q(HIROSE) => q(HIROSE Masaaki),
     q(HMA) => q(Henning Manske),
     q(HSW) => q(Sergey Homenkow),
@@ -228,6 +239,7 @@ use Acme::CPANAuthors::Register(
     q(IKEBE) => q(IKEBE Tomohiro),
     q(ILMARI) => q(Dagfinn Ilmari Mannsåker),
     q(INGY) => q(Ingy döt Net),
+    q(IOANR) => q(Ioan Rogers),
     q(IONCACHE) => q(Mark Jubenville),
     q(IRONCAMEL) => q(Naveed Massjouni),
     q(ISHIGAKI) => q(Kenichi Ishigaki),
@@ -254,23 +266,26 @@ use Acme::CPANAuthors::Register(
     q(JKEGL) => q(Jeffrey Kegler),
     q(JKUTEJ) => q(Jozef Kutej),
     q(JLAVALLEE) => q(Jeff Lavallee),
-    q(JMASTROS) => q(James Mastros),
     q(JMATES) => q(Jeremy Mates),
     q(JMCNAMARA) => q(John McNamara),
     q(JONALLEN) => q(Jon Allen),
-    q(JQUELIN) => q(Jerome Quelin),
+    q(JONASBN) => q(jonasbn),
+    q(JQUELIN) => q(Jérôme Quelin),
+    q(JROBINSON) => q(Jess Robinson),
     q(JROCKWAY) => q(Jonathan Rockway),
     q(JSHIRLEY) => q(J. Shirley),
     q(JSWARTZ) => q(Jonathan Swartz),
+    q(JTPALMER) => q(Jeffrey T. Palmer),
     q(JTRAMMELL) => q(John J. Trammell),
     q(JUSTER) => q(Justin Davis),
     q(KAARE) => q(Kaare Rasmussen),
-    q(KAMIPO) => q(Ryuta Kamizono),
+    q(KABLAMO) => q(Eric D Johnson),
     q(KAORU) => q(Alex Balhatchet),
-    q(KARAVELOV) => q(Luben Karavelov),
+    q(KARASIK) => q(Dmitry Karasik),
     q(KARMAN) => q(Peter Karman),
     q(KARUPA) => q(Kenta Sato),
-    q(KAZEBURO) => q(長野雅広),
+    q(KAZEBURO) => q(Masahiro Nagano),
+    q(KCOWGILL) => q(Kent Cowgill),
     q(KEEDI) => q(김도형 - Keedi Kim),
     q(KENTARO) => q(Kentaro Kuribayashi),
     q(KENTNL) => q(Kent Fredric),
@@ -279,31 +294,35 @@ use Acme::CPANAuthors::Register(
     q(KIMBREL) => q(Sam Kimbrel),
     q(KIMOTO) => q(Yuki Kimoto),
     q(KITANO) => q(dann),
-    q(KIXX) => q(Christian-Rolf Grün),
     q(KJETILK) => q(Kjetil Kjernsmo),
     q(KMCGRATH) => q(Kevin C. McGrath),
     q(KMX) => q(kmx),
+    q(KONOBI) => q(Scott McWhirter),
+    q(KOORCHIK) => q(Viktor Tuskyi),
     q(KOST) => q(Vlatko Košturjak),
     q(KRISTINA) => q(Kristina Chodorow),
+    q(KSURI) => q(Алексей Суриков),
+    q(KTAT) => q(加藤敦),
     q(KTHAKORE) => q(Kartik Thakore),
     q(KUNIYOSHI) => q(Kuniyoshi Kouji),
     q(KVORG) => q(Jan Jona Javoršek),
+    q(KWILLIAMS) => q(Ken Williams),
     q(LACKITA) => q(Colin Williams),
     q(LBROCARD) => q(Léon Brocard),
     q(LEEDO) => q(Lee Aylward),
     q(LEONT) => q(Leon Timmermans),
     q(LESPEA) => q(Adam Lesperance),
-    q(LETO) => q(Jonathan "Duke" Leto),
+    q(LETO) => q(Jonathan Leto),
+    q(LIFEGUARD) => q(Mike.lifeguard),
     q(LIMAONE) => q(LIMAONE),
     q(LKUNDRAK) => q(Lubomir Rintel),
     q(LLAP) => q(Leo Lapworth),
-    q(LTRIANT) => q(Luke Triantafyllidis),
+    q(LRR) => q(Luis M Rodríguez-R),
     q(LUKEC) => q(Luke Closs),
     q(MADCAT) => q(Ben van Staveren),
     q(MAESTRO) => q(Geoffrey Darling),
     q(MAKAMAKA) => q(Makamaka Hannyaharamitu),
     q(MALA) => q(ma la),
-    q(MALLRED) => q(Mike Allred),
     q(MANNI) => q(Manni Heumann),
     q(MARCEL) => q(Marcel Grünauer),
     q(MARKF) => q(Mark Fowler),
@@ -312,10 +331,16 @@ use Acme::CPANAuthors::Register(
     q(MART) => q(Martin Atkins),
     q(MASAKI) => q(Masaki Nakagawa),
     q(MASARTZ) => q(Masaru Hoshino),
+    q(MATEU) => q(Mateu X. Hunter),
+    q(MATTK) => q(Matt Koscica),
     q(MATTN) => q(Yasuhiro Matsumoto),
     q(MATTP) => q(Matthew Phillips),
+    q(MAUKE) => q(Lukas Mai),
     q(MAVERICK) => q(Maverick),
     q(MBARBON) => q(Mattia Barbon),
+    q(MBRADLEY) => q(Michael Bradley, Jr.),
+    q(MCAST) => q(Matthew Astley),
+    q(MCMAHON) => q(Joe McMahon),
     q(MDIETRICH) => q(Matthias Dietrich),
     q(MDOM) => q(Mario Domgörgen),
     q(MEETTYA) => q(Карпич Дмитрий),
@@ -325,7 +350,8 @@ use Acme::CPANAuthors::Register(
     q(MFONTANI) => q(Marco Fontani),
     q(MGRIMES) => q(Mark Grimes),
     q(MICHELEON) => q(michele ongaro),
-    q(MIKEGRB) => q(Rev Michael Greb),
+    q(MICHIELB) => q(Michiel Beijen),
+    q(MIKEGRB) => q(Michael Greb),
     q(MIKIHOSHI) => q(KAN Fushihara),
     q(MILAD) => q(Milad Rastian),
     q(MINIMAL) => q(minimalist),
@@ -334,7 +360,6 @@ use Acme::CPANAuthors::Register(
     q(MITHALDU) => q(Christian Walde),
     q(MITHUN) => q(Mithun Ayachit),
     q(MIYAGAWA) => q(Tatsuhiko Miyagawa),
-    q(MIZZY) => q(Gosuke Miyashita),
     q(MJGARDNER) => q(Mark Gardner),
     q(MLAWREN) => q(Mark Lawrence),
     q(MMCLERIC) => q(Вячеслав Матюхин),
@@ -343,8 +368,8 @@ use Acme::CPANAuthors::Register(
     q(MONSIEUR) => q(Monsieur Video),
     q(MORITZ) => q(Moritz Lenz),
     q(MORIYA) => q(MORIYA Masaki (守屋 雅樹)),
+    q(MOSHEN) => q(Colin Kennedy),
     q(MOTEMEN) => q(モテメン),
-    q(MRA) => q(Mark Atwood),
     q(MRAMBERG) => q(Marcus Ramberg),
     q(MRGRIPH) => q(Dmitriy V. Simonov),
     q(MROZ) => q(Ray Mroz),
@@ -356,38 +381,41 @@ use Acme::CPANAuthors::Register(
     q(MUIR) => q(David Muir Sharnoff),
     q(MXEY) => q(Maximilian Gaß),
     q(NCLEATON) => q(Nick Cleaton),
+    q(NEILB) => q(Neil Bowers),
     q(NEKOKAK) => q(Atsushi Kobayashi),
     q(NEVESENIN) => q(Merten Falk),
     q(NGRUNWALD) => q(Nils Grunwald),
     q(NGS) => q(Atsushi NAGASE - 長瀬 敦史),
     q(NIERLEIN) => q(Sven Nierlein),
     q(NIGELM) => q(Nigel Metheringham),
+    q(NMCFARL) => q(Nathan McFarland),
     q(NORBU) => q(Lenz Gschwendtner),
     q(NOTBENH) => q(ben hengst),
     q(NPEREZ) => q(Nicholas Perez),
     q(NPLATONOV) => q(Nickolay Platonov),
-    q(NUCLON) => q(Анатолий),
+    q(NPW) => q(Nick Stokoe),
     q(NUFFIN) => q(יובל קוג'מן (Yuval Kogman)),
     q(NWELLNHOF) => q(Nick Wellnhofer),
     q(OALDERS) => q(Olaf Alders),
+    q(ODYNIEC) => q(Michał Wojciechowski),
     q(OISHI) => q(Eisuke Oishi),
     q(OKAMUUU) => q(Masao Okamura),
     q(OKKO) => q(Oskari Ojala),
     q(OLEG) => q(Oleg G),
     q(OLIVER) => q(Oliver Gorwits),
-    q(OLOF) => q(Olof Johansson),
     q(OPERA) => q(Opera Software ASA),
     q(OTY) => q(Oleksandr Tymoshenko),
     q(OVID) => q(Curtis "Ovid" Poe),
     q(PATCH) => q(Nick Patch),
+    q(PAWAPAWA) => q(Kouhei Yoshioka (pawa)),
+    q(PBOYD) => q(Paul Boyd),
     q(PDCAWLEY) => q(Piers Cawley),
     q(PDONELAN) => q(Patrick Donelan),
-    q(PENFOLD) => q(Penfold),
     q(PEPL) => q(Michael Kröll),
     q(PERIGRIN) => q(Chris Prather),
     q(PERLER) => q(Moritz Onken),
+    q(PERLISH) => q(seyed hadi hosseini),
     q(PETDANCE) => q(Andy Lester),
-    q(PFIG) => q(Pedro Figueiredo),
     q(PFISCHER) => q(Pablo Fischer),
     q(PHAYLON) => q(Robert 'phaylon' Sedlacek),
     q(PHILIP) => q(Philip Garrett),
@@ -400,6 +428,7 @@ use Acme::CPANAuthors::Register(
     q(PMORCH) => q(Peter Valdemar Mørch),
     q(PNU) => q(Panu Ervamaa),
     q(POTYL) => q(Emmanuel Rodriguez),
+    q(PROFANTER) => q(Stefan Profanter),
     q(PSHANGOV) => q(Peter Shangov),
     q(PUNYTAN) => q(プニプニ),
     q(PVANDE) => q(Pieter van de Bruggen),
@@ -408,9 +437,9 @@ use Acme::CPANAuthors::Register(
     q(RBO) => q(Robert Bohne),
     q(RBUELS) => q(Robert Buels),
     q(RCAPUTO) => q(Rocco Caputo),
-    q(RCLAMP) => q(Richard Clamp),
     q(REDICAPS) => q(woosley),
     q(RENTOCRON) => q(Renato Santos de Souza),
+    q(REVMISCHA) => q(Mischa Spiegelmock),
     q(RGARCIA) => q(Rafaël Garcia-Suarez),
     q(RGE) => q(Robin Edwards),
     q(RHESA) => q(Rhesa Rozendaal),
@@ -426,43 +455,45 @@ use Acme::CPANAuthors::Register(
     q(ROBINS) => q(Robin Smidsrød),
     q(ROBN) => q(Robert Norris),
     q(RODRIGO) => q(Rodrigo de Oliveira Gonzalez),
+    q(RSIMOES) => q(Richard Simões),
     q(RSRCHBOY) => q(Chris Weyl),
     q(RTHOMPSON) => q(Ryan C. Thompson),
     q(RUBYKAT) => q(Kathryn Andersen),
     q(RURBAN) => q(Reini Urban),
     q(RUSSOZ) => q(Alexei Znamensky),
-    q(RVOSA) => q(Rutger Vos),
     q(RWSTAUNER) => q(Randy Stauner),
     q(SABECK) => q(Scott Beck),
     q(SALVA) => q(Salvador Fandiño García),
     q(SANKO) => q(Sanko Robinson),
     q(SAPER) => q(Sébastien Aperghis-Tramoni),
+    q(SARGIE) => q(Peter Sergeant),
     q(SARTAK) => q(Shawn M Moore),
     q(SATOH) => q(cho45 (さとう)),
     q(SAUBER) => q(Søren Døssing),
     q(SAYMEDIA) => q(SAY MEDIA),
-    q(SCHUBIGER) => q(Steven Schubiger (stsc)),
     q(SCHWIGON) => q(Steffen Schwigon),
     q(SCLOUSE) => q(Stephen Clouse),
     q(SDECASTE) => q(sebastian de castelberg),
+    q(SDEN) => q(Λόρδος Σπύρος Δεναξάς),
+    q(SDT) => q(Stephen Thirlwall),
     q(SEKIMURA) => q(Masayoshi Sekimura),
     q(SGRAHAM) => q(Sam Graham),
     q(SHABBLE) => q(Tom Feist),
     q(SHANTANU) => q(Shantanu Bhadoria),
     q(SHARIFULN) => q(Анатолий Шарифулин),
     q(SHARYANTO) => q(Steven Haryanto),
+    q(SHAW) => q(sshaw),
     q(SHEENAMS) => q(Sheena Scroggins),
     q(SHELLING) => q(許家瑋),
-    q(SHIGETA) => q(Takatsugu Shigeta),
+    q(SHERWIN) => q(Sherwin Daganato),
     q(SHLOMIF) => q(Shlomi Fish),
+    q(SHUFF) => q(Steve Huff),
     q(SIDD) => q(Siddhartha Basu),
     q(SILASMONK) => q(Nicholas Bamber),
+    q(SIMONW) => q(Simon Wistow),
     q(SIXAPART) => q(Six Apart Ltd.),
-    q(SJN) => q(Salve J. Nilsen),
-    q(SKIM) => q(Michal Špaček),
-    q(SKNPP) => q(Sebastian Knapp),
+    q(SLU) => q(Søren Lund),
     q(SMUELLER) => q(Steffen Müller),
-    q(SPANG) => q(Christine Spang),
     q(SPARKY) => q(Przemysław Iskra),
     q(SPAZM) => q(Andrew Grangaard),
     q(SQUEEK) => q(Squeeks),
@@ -471,6 +502,7 @@ use Acme::CPANAuthors::Register(
     q(SSCAFFIDI) => q(Stephen R. Scaffidi),
     q(SSEVERIN) => q(Steven N. Severinghaus),
     q(STASH) => q(Jeremy Stashewsky),
+    q(STEPHANJ) => q(Stephan Jauernick),
     q(STEVAN) => q(Stevan Little),
     q(STRUAN) => q(Struan Donald),
     q(SUGOIK) => q(K. Ford),
@@ -479,12 +511,16 @@ use Acme::CPANAuthors::Register(
     q(SUNNAVY) => q(孙海军),
     q(SVIEBROCK) => q(Seth Viebrock),
     q(SWALTERS) => q(Scott Walters),
+    q(SYMKAT) => q(SymKat),
     q(SYOHEX) => q(Syohei Yoshida),
     q(SYP) => q(Станислав Пусеп),
     q(SZABGAB) => q(גאבור סבו - Gábor Szabó),
     q(SZBALINT) => q(Bálint Szilakszi),
+    q(TADAM) => q(Yury Zavarin),
     q(TARO) => q(小松 大輔(Daisuke Komatsu)),
+    q(TATENO) => q(Yuichi Tateno),
     q(TBR) => q(Thiago Berlitz Rondon),
+    q(TEEJAY) => q(Aaron James Trevena),
     q(TEMPIRE) => q(Glen Hinkle),
     q(THALJEF) => q(Jeffrey Ryan Thalhammer),
     q(THOLEN) => q(Thomas Lenz),
@@ -492,18 +528,23 @@ use Acme::CPANAuthors::Register(
     q(TIMB) => q(Tim Bunce),
     q(TJC) => q(Toby Corkindale),
     q(TJENNESS) => q(Tim Jenness),
+    q(TMUELLER) => q(Thomas Müller),
     q(TOBYINK) => q(Toby Inkster),
     q(TODDR) => q(Todd Rinaldo),
+    q(TOKAREV) => q(Alexander Tokarev),
     q(TOKUHIROM) => q(MATSUNO★Tokuhiro),
     q(TOMELIAZ) => q(Tom Eliaz),
     q(TOMFAHLE) => q(Thomas Fahle),
     q(TOMITA) => q(Naoki Tomita (tomi-ru)),
+    q(TONYC) => q(Tony Cook),
+    q(TRCJR) => q(Theodore Robert Campbell Jr),
+    q(TRON) => q(Traian Nedelea),
     q(TSUCCHI) => q(Takuya Tsuchida),
     q(TYPESTER) => q(Daisuke Murase),
+    q(UASI) => q(Tomoki Aonuma),
     q(UNDEF) => q(Сергей Засенко),
     q(UNOBE) => q(David Romano),
     q(USUALOMA) => q(Taku Amano),
-    q(UVOELKER) => q(Uwe Voelker),
     q(VDG) => q(Valentin D Guillois),
     q(VESELOSKY) => q(Vincent E. Veselosky),
     q(VKON) => q(Vadim Konovalov),
@@ -512,14 +553,18 @@ use Acme::CPANAuthors::Register(
     q(VTI) => q(Вячеслав Тихановский),
     q(VVU) => q(Alex White (wu)),
     q(WARRINGD) => q(David Warring),
+    q(WINTER) => q(Becca Turner),
     q(WOLDRICH) => q(Magnus Woldrich),
-    q(WOLFSAGE) => q(Matthew Horsfall),
+    q(WOLFSAGE) => q(Matthew Horsfall (alh)),
     q(WOLVERIAN) => q(Ilmari Vacklin),
     q(WONKO) => q(Michael Peters),
+    q(WORR) => q(William Orr),
     q(WREIS) => q(Wallace Reis),
+    q(WROG) => q(Roger Crew),
     q(WSDOOKADR) => q(Petrea Corneliu Ştefan),
+    q(WULEE) => q(Nick Stokoe),
+    q(WWOLF) => q(William Wolf),
     q(XAICRON) => q(Yuji Shimada),
-    q(XANTUS) => q(David Davis),
     q(XENO) => q(Caleb Cushing),
     q(XIONG) => q(Xiong Changnian),
     q(XSAWYERX) => q(Sawyer X),
@@ -536,14 +581,14 @@ use Acme::CPANAuthors::Register(
     q(ZAKAME) => q(Zak B. Elep),
     q(ZBY) => q(Zbigniew Łukasiak),
     q(ZDK) => q(Warachet Samtalee),
-    q(ZENOG) => q(Zeno Gantner),
+    q(ZEFRAM) => q(Andrew Main (Zefram)),
     q(ZENTOOO) => q(Naosuke Yokoe),
     q(ZERO) => q(Oleg Alistratov),
     q(ZEROHP) => q(Eric Clark),
     q(ZIGOROU) => q(Toru Yamaguchi),
-    q(ZIGUZAGU) => q(Hiroshi Sakai),
     q(ZOUL) => q(Tomáš Znamenáček),
     q(ZWON) => q(Pavel Shaydo),
+    q(ZZZ) => q(Alexandr Gomoliako),
 );
 
 
@@ -630,4 +675,3 @@ under the same terms as Perl itself.
 gray, <gray at cpan.org>
 
 =cut
-__EOF__
